:github_url: https://github.com/j-bac/elpigraph-python/tree/master/elpigraph-python/elpigraph/plot.py#L1258-L1337



elpigraph.plot.PlotPG
=====================

.. currentmodule:: elpigraph.plot

.. autofunction:: PlotPG